@@ -53,6 +53,7 @@ def __createPermissions(session,permissions):
         if not perm:
             perm = PPSspermission(name = p['name'])
             session.add(perm)
+            l.info("permission '{}' added to session".format(p['name']))
         perm.permtype = p['permtype'] if 'permtype' in p else 0
         permmap[p['name'] ] = perm
     return permmap
@@ -70,6 +71,7 @@ def __createGroups(session,groups,permissions):
         if not group:
             group = PPSsgroup(name = gname)
             session.add(group)
+            l.info("group '{}' added to session".format(gname))
         groupmap[gname] = group
         for p in permlist:
             if not group.hasPermission(p):
@@ -79,6 +81,7 @@ def __createGroups(session,groups,permissions):
                     perm = PPSspermission(name = p,permtype = 0)
                     session.add(perm)
                     permissions[p] = perm
+                    l.info("new permission '{}' created for group '{}'".format(p,gname))
                 group.permissions.append(perm)
     return groupmap
 
@@ -86,7 +89,13 @@ def __createUsers(session,users,groups,defaultpassword = None):
     usermap = {}
     for u in users:
         u = u.split("=")
-        uname = str.strip(u[0])
+        uname = u[0].split("/")
+        upassword = None
+        if len(uname)==2:
+            upassword = uname[1].strip()
+        else: 
+            upassword = Conf.defaultpassword
+        uname = uname[0].strip()
         if len(u)==2:
             grouplist = map(str.strip,u[1].split(","))
         else:
@@ -94,17 +103,25 @@ def __createUsers(session,users,groups,defaultpassword = None):
         user = session.query(PPSsuser).filter(PPSsuser.username == uname).first()
         if not user:
             user = PPSsuser(username = uname)
-            if Conf.defaultpassword:
-                user.setPassword(defaultpassword if defaultpassword else Conf.defaultpassword)
+            if upassword or defaultpassword:
+                user.setPassword(upassword)
+            elif defaultpassword:
+                user.setPassword(defaultpassword)
             session.add(user)
+            l.info("user '{}' added to session".format(uname))
         usermap[uname] = user
         for g in grouplist:
             if not user.isInGroup(g,False):
                 if g in groups:
                     group = groups[g]
                 else:
-                    group = PPSsgroup(name = g)
-                    session.add(group)
+                    group = session.query(PPSsgroup).filter(PPSsgroup.name == g).first()
+                    if group is None:
+                        group = PPSsgroup(name = g)
+                        session.add(group)
+                    else:
+                        groups[g] = group
+                    l.info("new group '{}' created for user '{}'".format(g,uname))
                 user.groups.append(group)
     return usermap
 
@@ -196,7 +213,7 @@ class commonTable():
 class PPSsuser(Base,commonTable):
     __tablename__   = 'ppss_user'
     id              = Column(Integer, primary_key=True)
-    username        = Column(Unicode(128))
+    username        = Column(Unicode(128),unique=True)
     password        = Column(Unicode(1024))
     insertdt        = Column(DateTime,default=datetime.now)
     updatedt        = Column(DateTime,default=datetime.now,onupdate=datetime.now)
