@@ -12,10 +12,6 @@ def main(argv=sys.argv):
   config_uri = argv[-1]
   setup_logging(config_uri)
   inihere = os.getcwd()
-  here = os.path.join(str(__path__[0]),"..")
-  #out = subprocess.Popen('alembic -x sqluri={} -x cwd={} upgrade head'.format(config_uri,inihere).split(" "), 
-  #         stdout=subprocess.PIPE, 
-  ##         stderr=subprocess.STDOUT,
-  #         workingdir=here)
-  #stdout,stderr = out.communicate()
+  here = os.path.join(str(__path__[0]),"alembic")
+  l.info("cwd:{} sqluri ini:{}".format(here,config_uri))
   subprocess.call('alembic -x sqluri={} -x cwd={} upgrade head'.format(config_uri,inihere).split(" "), cwd = here)
