@@ -42,13 +42,17 @@ class ACLBuilder(object):
 
     @cache_region('short_term', 'ACLpermissions')
     def buildACL(self):
-        groups = self.session.query(PPSsgroup).filter(PPSsgroup.enabled==1).all()
+        
         acl = [] 
-        for group in groups:
-            acl.append( (Allow,
-                    str("g:"+group.name),
-                    tuple([str(p.name) for p in group.permissions])  
-            ) )
+        try:
+            groups = self.session.query(PPSsgroup).filter(PPSsgroup.enabled==1).all()
+            for group in groups:
+                acl.append( (Allow,
+                        str("g:"+group.name),
+                        tuple([str(p.name) for p in group.permissions])  
+                ) )
+        except Exception as e:
+            l.exception("called without a transaction")
         acl = self.baseACL + acl
         l.warn("ACLBuilder:acl built: {acl}".format(acl = acl))
         return acl
@@ -97,8 +101,12 @@ class AuthController():
             pass
 
         #for all ops on users, get the target user
-        self.userid = int(self.request.matchdict.get("elementid",
-            self.request.session[Conf.sessionuser]['id'] if Conf.sessionuser in self.request.session else -1 ) )
+        self.userid = int(
+            self.request.params.get("userid",
+                self.request.matchdict.get("elementid",
+                    self.request.session[Conf.sessionuser]['id'] if Conf.sessionuser in self.request.session else -1 ) 
+                )
+            )
         self.user = self.getUserById(self.userid)
         
 
@@ -122,9 +130,19 @@ class AuthController():
             self.request.referer, 
             self.request.route_url("ppsslogin"),
             r.route_url(Conf.postloginroute), (self.request.referer and self.request.referer!=self.request.route_url("ppsslogin")) )   )
+        if self.request.referer:
+            if self.request.loggeduser:
+                signinreason = "Your current account has insufficent rights to view the page you requested.</br>You can change the account you are using with a new login."
+            else:
+                signinreason = "Please login to view the requested content."
+        else:
+            signinreason = ""
+        self.retdict["signinreason"] = signinreason
+
         self.request.session['postloginpage'] = postloginpage
         if self.user and self.user.passwordExpired():
-                return HTTPFound(r.route_url("ppss:user:changepassword"))
+            return HTTPFound(r.route_url("ppss:user:changepassword"))
+
         if r.POST:
             username = r.params.get("username",u"")
             password = r.params.get("password",u"")
@@ -260,6 +278,8 @@ class AuthController():
             submiturl = self.request.route_url('ppss:user:editself')
             selfediting = True
         else:
+            if userid == self.request.loggeduser.id:
+                selfediting = True
             submiturl = self.request.route_url('ppss:user:edit',elementid=userid)
 
         l.debug("***{id} -> {user}".format(user=user,id=userid))
@@ -269,23 +289,34 @@ class AuthController():
             retdict['msg'] = "user not found"
 
         editablegroups = []
-        logged_id = self.request.session[Conf.sessionuser]['id']
-        logged_user = self.getUserById(logged_id)
 
-        
+        logged_user = self.request.loggeduser
+
+        l.info("logged user is superuser? {}".format(logged_user.isSuperUser()))
         if logged_user.isSuperUser():
             editablegroups = PPSsgroup.all(self.request.dbsession)
-        if logged_user.hasPermission('edituser') or selfediting:
-            editablegroups =  logged_user.groups
+        elif logged_user.hasPermission('edituser') or selfediting:
+            editablegroups = logged_user.groups
         l.debug("editablegroups = {}".format(editablegroups))
 
         retdict.update({"user" : user, 'allgroups':editablegroups })
 
         if self.request.POST:
-            username = user.username
+            canenable = True
             if userid<0:
+                username = self.request.params.get("username",None)
+                if not username:
+                    retdict['msg'] = "Username can not be empty."
+                    return retdict
+                if len(PPSsuser.byField("username",username,self.request.dbsession))>0:
+                    retdict['msg'] = "Username '{}' already used.".format(username)
+                    return retdict
                 self.request.dbsession.add(user)
-                user.username = self.request.params.get("username",user.username)
+                user.username = username
+                #default for new user is "Cant enable". Can be enabled ony if a valid password is supplied
+                canenable = False
+            username = user.username
+
             if not user:
                 return retdict
             newpassword = self.request.params.get("password","")
@@ -294,9 +325,10 @@ class AuthController():
                 confirmnewpassword = self.request.params.get("confirmnewpassword","")
                 currentpassword = self.request.params.get("currentpassword","")
 
-                #existing user must match older password
-                if userid>=0 and (not PPSsuser.checkLogin(username,currentpassword,self.request.dbsession)): 
-                    retdict['msg'] = "your current password does not match" 
+                #existing user must match older password (unless edited by superadmin)
+                if (self.request.loggeduser.isSuperUser() == False) or selfediting:
+                    if userid>=0 and (not PPSsuser.checkLogin(username,currentpassword,self.request.dbsession)): 
+                        retdict['msg'] = "your current password does not match" 
 
                 elif newpassword==confirmnewpassword:
                     l.info("*****changing password for {}".format(user.username) )
@@ -304,11 +336,13 @@ class AuthController():
                     l.info("checkPassword result for user {} = {}".format(user.username, res ))
                     if res:
                         user.setPassword(newpassword)
+                        retdict['msg'] = "password updated."
+                        canenable = True
                     else:
                         retdict['msg'] = "new password doesn't match constraints." 
                 else:
                     retdict['msg'] = "new password doesn't match confirmation field." 
-            user.enabled = 1 if self.request.params.get("enabled")=="1" else 0
+            user.enabled = 1 if self.request.params.get("enabled")=="1" and canenable else 0
             
             groups=map(int,self.request.params.getall("allgroups"))
             l.debug("group={groups}".format(groups=groups ))
